==> aws-java-sdk-ssm-1.10.25-sources.jar: com/amazonaws/services/simplesystemsmanagement/model/transform/FailedCreateAssociationJsonMarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simplesystemsmanagement.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.simplesystemsmanagement.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * FailedCreateAssociationMarshaller
 */
public class FailedCreateAssociationJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(FailedCreateAssociation failedCreateAssociation,
            JSONWriter jsonWriter) {
        if (failedCreateAssociation == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (failedCreateAssociation.getEntry() != null) {
                jsonWriter.key("Entry");
                CreateAssociationBatchRequestEntryJsonMarshaller.getInstance()
                        .marshall(failedCreateAssociation.getEntry(),
                                jsonWriter);
            }

            if (failedCreateAssociation.getMessage() != null) {
                jsonWriter.key("Message").value(
                        failedCreateAssociation.getMessage());
            }

            if (failedCreateAssociation.getFault() != null) {
                jsonWriter.key("Fault").value(
                        failedCreateAssociation.getFault());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static FailedCreateAssociationJsonMarshaller instance;

    public static FailedCreateAssociationJsonMarshaller getInstance() {
        if (instance == null)
            instance = new FailedCreateAssociationJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-ssm-1.10.77-sources.jar: com/amazonaws/services/simplesystemsmanagement/model/transform/FailedCreateAssociationJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simplesystemsmanagement.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.simplesystemsmanagement.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * FailedCreateAssociationMarshaller
 */
public class FailedCreateAssociationJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(FailedCreateAssociation failedCreateAssociation,
            StructuredJsonGenerator jsonGenerator) {

        if (failedCreateAssociation == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (failedCreateAssociation.getEntry() != null) {
                jsonGenerator.writeFieldName("Entry");
                CreateAssociationBatchRequestEntryJsonMarshaller.getInstance()
                        .marshall(failedCreateAssociation.getEntry(),
                                jsonGenerator);
            }
            if (failedCreateAssociation.getMessage() != null) {
                jsonGenerator.writeFieldName("Message").writeValue(
                        failedCreateAssociation.getMessage());
            }
            if (failedCreateAssociation.getFault() != null) {
                jsonGenerator.writeFieldName("Fault").writeValue(
                        failedCreateAssociation.getFault());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static FailedCreateAssociationJsonMarshaller instance;

    public static FailedCreateAssociationJsonMarshaller getInstance() {
        if (instance == null)
            instance = new FailedCreateAssociationJsonMarshaller();
        return instance;
    }

}
